## Copyright (C) 1998 Ariel Tankus
## 
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##

## double    Convert the characters of a string into its representation
##           as a matrix of ascii codes.
##

## Author: Ariel Tankus <arielt@math.tau.ac.il>
## Created: 15.6.98
## Version: 1.0

function d = double(in)

  if isstr(in)
      d = mod(in+0,256);
  else
      d = in;
  end

endfunction
